A collection of modulators.
Structs
- Hold
- Emit first value before the given moment and the second value after.
- Linear
- Linearly ramp up or cut down from one value to another on the given time interval.
- Sine
- Sine wave low-frequency oscillator.
Traits
- Modulator
- An audio node parameter modulator.